/***************************************************************************
 *   Copyright (C) 2007 by Felix H. Dahlke                                 *
 *   fhd@ubercode.de                                                       *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#include "binaryclock.h"
#include "kbcconfiguration.h"
#include <qdatetime.h>
#include <qtimer.h>
#include <qpainter.h>

BinaryClock::BinaryClock(QWidget *parent) : QWidget(parent)
{}

BinaryClock::~BinaryClock()
{}

void BinaryClock::setConfig(KBCConfiguration *config)
{
	this->bit_shape = config->bit_shape;

	this->borderColor0 = config->borderColor0;
	this->fillColor0 = config->fillColor0;
	this->borderColor1 = config->borderColor1;
	this->fillColor1 = config->fillColor1;

	this->hxstart = config->hxstart;
	this->mxstart = config->mxstart;
	this->hystart = config->hystart;
	this->mystart = config->mystart;
	this->hxgap = config->hxgap;
	this->mxgap = config->mxgap;
	this->hxsize = config->hxsize;
	this->hysize = config->hysize;
	this->mxsize = config->mxsize;
	this->mysize = config->mysize;
}

void BinaryClock::start()
{
	QTimer *timer = new QTimer(this);
	connect(timer, SIGNAL(timeout()), this, SLOT(showTime()));
	timer->start(1000);

	showTime();
}


void BinaryClock::showTime()
{
	// getting the time and converting it to binary
	QTime time = QTime::currentTime();
	int hour = time.hour();
	int minute = time.minute();
	bool btime[10];

	btime[0] = btime[1] = btime[2] = btime[3] = btime[4] = btime[5] = btime[6] = btime[7] = btime[8] = btime[9] = false;

	if (hour > 12)
		hour -= 12;

	if (hour >= 8) {
		btime[0] = true;
		hour -= 8;
	}
	if (hour >= 4) {
		btime[1] = true;
		hour -= 4;
	}
	if (hour >= 2) {
		btime[2] = true;
		hour -= 2;
	}
	if (hour == 1)
		btime[3] = true;

	if (minute >= 32) {
		btime[4] = true;
		minute -= 32;
	}
	if (minute >= 16) {
		btime[5] = true;
		minute -= 16;
	}
	if (minute >= 8) {
		btime[6] = true;
		minute -= 8;
	}
	if (minute >= 4) {
		btime[7] = true;
		minute -= 4;
	}
	if (minute >= 2) {
		btime[8] = true;
		minute -= 2;
	}
	if (minute == 1)
		btime[9] = true;


	// drawing the clock
	QPainter *p = new QPainter(this);
	QPen p0, p1;
	QBrush b0, b1;
	p0.setColor(borderColor0);
	b0.setStyle(SolidPattern);
	b0.setColor(fillColor0);
	p1.setColor(borderColor1);
	b1.setStyle(SolidPattern);
	b1.setColor(fillColor1);

	// TODO: clear this before drawing again

	for (int i = 0; i < 4; i++) {
		if (btime[i]) {
			p->setPen(p1);
			p->setBrush(b1);
		} else {
			p->setPen(p0);
			p->setBrush(b0);
		}

		if (bit_shape == ELLIPSE)
			p->drawEllipse(hxstart + i*hxgap + i*hxsize, hystart, hxsize, hysize);
		else if (bit_shape == RECTANGLE)
			p->drawRect(hxstart + i*hxgap + i*hxsize, hystart, hxsize, hysize);
	}

	for (int i = 0; i < 6; i++) {
		if (btime[i + 4]) {
			p->setPen(p1);
			p->setBrush(b1);
		} else {
			p->setPen(p0);
			p->setBrush(b0);
		}

		if (bit_shape == ELLIPSE)
			p->drawEllipse(mxstart + i*mxgap + i*mxsize, mystart, mxsize, mysize);
		else if (bit_shape == RECTANGLE)
			p->drawRect(mxstart + i*mxgap + i*mxsize, mystart, mxsize, mysize);
	}
}
