/***************************************************************************
 *   Copyright (C) 2007 by Felix H. Dahlke                                 *
 *   fhd@ubercode.de                                                       *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/


#include <kglobal.h>
#include <klocale.h>
#include <kconfig.h>
#include <kapplication.h>
#include <kmessagebox.h>

#include "kbcconfiguration.h"
#include "binaryclock.h"
#include "kbcconfigwindow.h"
#include "binaryklock.h"


binaryklock::binaryklock(const
                           QString& configFile, Type type, int actions, QWidget *parent, const
                           char *name)
		: KPanelApplet(configFile, type, actions, parent, name)
{
	// Get the current application configuration handle
	ksConfig = config();
	kbcConfig = loadConfig();
	bClock = new BinaryClock(this);
	bClock->setConfig(kbcConfig);
	bClock->start();
	bClock->show();
}


binaryklock::~binaryklock()
{}

void binaryklock::about()
{
	KMessageBox::information(0, i18n("A binary clock.\nAuthor: Felix H. Dahlke fhd@ubercode.de\nVersion: 0.1\nhttp://ubercode.de"));
}


void binaryklock::help()
{
	KMessageBox::information(0, i18n("There are only 10 kinds of people in the world:\nThose who understand binary and those who don't.\n\nQuite popular t-shirt phrase. If you understand it, you can close this window now.\n\nIf not, learn binary.\n\nHonestly, it's not very hard, so I won't explain. What I will explain is how this clock represents the time.\nThe 4 bits above represent the hour, 0-12. If you did you homework, you will notice that there are not 12, but 16 possibilities. Well I don't care.\nThe 6 bits in the lower row represent the minutes, from 0-60. Again, there are more possibilities, so these bits won't ever all shine at the same time.\nThat's it for now. No seconds because I'm too lazy for that right now. And no date until I get a much bigger screen."));
}


void binaryklock::preferences()
{
	KBCConfigWindow *configWindow = new KBCConfigWindow(this, kbcConfig);
	connect(configWindow, SIGNAL(configUpdated(KBCConfiguration *)), this, SLOT(updateConfig(KBCConfiguration *)));
	configWindow->show();
}

KBCConfiguration *binaryklock::loadConfig()
{
	KBCConfiguration *config = new KBCConfiguration(ksConfig);

	return config;
}

void binaryklock::updateConfig(KBCConfiguration *config)
{
	kbcConfig = config;
	bClock->setConfig(kbcConfig);
}

int binaryklock::widthForHeight(int height) const
{
	return width();
}

int binaryklock::heightForWidth(int width) const
{
	return height();
}

void binaryklock::resizeEvent(QResizeEvent *e)
{}


extern "C"
{
	KPanelApplet* init(QWidget *parent, const
	                   QString& configFile) {
		KGlobal::locale()->insertCatalogue("binaryklock");
		return new binaryklock(configFile, KPanelApplet::Normal,
		                        KPanelApplet::About | KPanelApplet::Help | KPanelApplet::Preferences,
		                        parent, "binaryklock");
	}
}
